==> haskell-semigroups-0.18.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.3
id: semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
key: semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Semigroup.Generic
abi: 863c6a42773abd5c980b4318cc858c44
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/semigroups-0.18.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/semigroups-0.18.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/semigroups-0.18.3
hs-libraries: HSsemigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semigroups-0.18.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.4
id: semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
key: semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Semigroup.Generic
abi: c739600aa012ae17eb506df1a043419b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/semigroups-0.18.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/semigroups-0.18.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/semigroups-0.18.4
hs-libraries: HSsemigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
